        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 27 <br>2,3,6,9,12,13,15,20,21,22,23,26,28,30,31,32,33,36,37,38,39,41,44,45,46,48,49';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 24 <strong>control</strong><br>0,1,4,5,7,8,10,11,14,16,17,18,19,24,25,27,29,34,35,40,42,43,47,50';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 27 <br>2,3,6,9,12,13,15,20,21,22,23,26,28,30,31,32,33,36,37,38,39,41,44,45,46,48,49';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 24 <strong>control</strong><br>0,1,4,5,7,8,10,11,14,16,17,18,19,24,25,27,29,34,35,40,42,43,47,50';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 27 <br>2,3,6,9,12,13,15,20,21,22,23,26,28,30,31,32,33,36,37,38,39,41,44,45,46,48,49';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 24 <strong>control</strong><br>0,1,4,5,7,8,10,11,14,16,17,18,19,24,25,27,29,34,35,40,42,43,47,50';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 27 <br>2,3,6,9,12,13,15,20,21,22,23,26,28,30,31,32,33,36,37,38,39,41,44,45,46,48,49';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 24 <strong>control</strong><br>0,1,4,5,7,8,10,11,14,16,17,18,19,24,25,27,29,34,35,40,42,43,47,50';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 27 <br>2,3,6,9,12,13,15,20,21,22,23,26,28,30,31,32,33,36,37,38,39,41,44,45,46,48,49';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 24 <strong>control</strong><br>0,1,4,5,7,8,10,11,14,16,17,18,19,24,25,27,29,34,35,40,42,43,47,50';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 27 <br>2,3,6,9,12,13,15,20,21,22,23,26,28,30,31,32,33,36,37,38,39,41,44,45,46,48,49';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260509 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 24 <strong>control</strong><br>0,1,4,5,7,8,10,11,14,16,17,18,19,24,25,27,29,34,35,40,42,43,47,50';}
}
